@@ -2,14 +2,12 @@
 
 Also supports the `-l` option.
 
+The "Magic" syntax is not supported since the `jobs` command is a shell builtin.
+
 Usage (cli):
 
     $ jobs | jc --jobs
 
-    or
-
-    $ jc jobs
-
 Usage (module):
 
     import jc.parsers.jobs
