@@ -85,7 +85,7 @@ def has_data(data):
 
 def convert_to_int(value):
     """
-    Converts string input to integer by stripping all non-numeric characters
+    Converts string and float input to int. Strips all non-numeric characters from strings.
 
     Parameters:
 
@@ -96,11 +96,12 @@ def convert_to_int(value):
         integer/None    Integer if successful conversion, otherwise None
     """
     if isinstance(value, str):
+        str_val = re.sub(r'[^0-9\-\.]', '', value)
         try:
-            return int(re.sub(r'[^0-9\-\.]', '', value))
-        except ValueError:
+            return int(str_val)
+        except (ValueError, TypeError):
             try:
-                return int(convert_to_float(value))
+                return int(float(str_val))
             except (ValueError, TypeError):
                 return None
 
@@ -113,7 +114,7 @@ def convert_to_int(value):
 
 def convert_to_float(value):
     """
-    Converts string input to float by stripping all non-numeric characters
+    Converts string and int input to float. Strips all non-numeric characters from strings.
 
     Parameters:
 
@@ -238,6 +239,9 @@ class timestamp:
         }
         utc_tz = False
 
+        # sometimes UTC is referenced as 'Coordinated Universal Time'. Convert to 'UTC'
+        data = data.replace('Coordinated Universal Time', 'UTC')
+
         if 'UTC' in data:
             utc_tz = True
             if 'UTC+' in data or 'UTC-' in data:
@@ -253,6 +257,7 @@ class timestamp:
             {'id': 1500, 'format': '%Y-%m-%d %H:%M', 'locale': None},  # en_US.UTF-8 local format (found in who cli output): 2021-03-23 00:14
             {'id': 1600, 'format': '%m/%d/%Y %I:%M %p', 'locale': None},  # Windows english format (found in dir cli output): 12/07/2019 02:09 AM
             {'id': 1700, 'format': '%m/%d/%Y, %I:%M:%S %p', 'locale': None},  # Windows english format wint non-UTC tz (found in systeminfo cli output): 3/22/2021, 1:15:51 PM (UTC-0600)
+            {'id': 1705, 'format': '%m/%d/%Y, %I:%M:%S %p %Z', 'locale': None},  # Windows english format with UTC tz (found in systeminfo cli output): 3/22/2021, 1:15:51 PM (UTC)
             {'id': 1710, 'format': '%m/%d/%Y, %I:%M:%S %p UTC%z', 'locale': None},  # Windows english format with UTC tz (found in systeminfo cli output): 3/22/2021, 1:15:51 PM (UTC+0000)
             {'id': 2000, 'format': '%a %d %b %Y %I:%M:%S %p %Z', 'locale': None},  # en_US.UTF-8 local format (found in upower cli output): Tue 23 Mar 2021 04:12:11 PM UTC
             {'id': 3000, 'format': '%a %d %b %Y %I:%M:%S %p', 'locale': None},  # en_US.UTF-8 local format with non-UTC tz (found in upower cli output): Tue 23 Mar 2021 04:12:11 PM IST
